@@ -50,8 +50,6 @@ function mapUbuntuNameToDep {
   esac
 }
 
-GET="scp ftpubuntu@ftpmaster.kde.org:/home/ftpubuntu"
-
 clean_dld=1
 subset=""
 
@@ -77,10 +75,15 @@ case ${WDIR##*/} in
     cd ..;;
   "build" )
     cd ..;;
-  "kubuntu-kde-l10n-common" )
+  "kde-l10n-common" )
     ;;
 esac
 
+if ! source debian/config ; then
+    echo "could not source config!!"
+    exit 1
+fi
+
 if [ -e build ]; then
   echo "A already existing build/ directory was found, which indicates that there was a build done earlier."
   echo "Note: you can also run this script with -ncd to preserve only the tar.bz2 files from build/."
@@ -104,8 +107,6 @@ fi
 cd build
 WDIR=`pwd`
 
-BRANCH="lp:~kubuntu-packagers/kubuntu-packaging/kde-l10n-common-natty-archive"
-CO="common"
 BOILERPLATE="# ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! !#\n# DO NOT EVEN THINK ABOUT CHANGING THIS FILE DIRECTLY! ! ! !\n# PLEASE USE THE BZR BRANCH AS SEEN IN debian\/control\n# MAKE YOUR CHANGES THERE AND THEN RUN debian\/build-l10n.sh\n# kthxbai :)\n################################################################################\n################################################################################\n################################################################################\n################################################################################"
 
 if [[ `bzr revno` != `bzr revno ${BRANCH}` ]]; then
@@ -133,11 +134,11 @@ cd build-area
 if [ $clean_dld -ne 0 ]; then
   if [[ "$subset" == "" ]]; then
     # get all
-    $GET/stable/${KDEVERSION}/src/kde-l10n/kde-l10n-*.tar.bz2 .
+    $GET/${TYPE}/${KDEVERSION}/src/kde-l10n/kde-l10n-*.tar.bz2 .
   else
     # only get subset
     for pkg in $subset; do
-      $GET/stable/${KDEVERSION}/src/kde-l10n/kde-l10n-$pkg-*.tar.bz2 .
+      $GET/${TYPE}/${KDEVERSION}/src/kde-l10n/kde-l10n-$pkg-*.tar.bz2 .
     done
   fi
 fi
@@ -194,6 +195,6 @@ for tfile in `ls kde-l10n-*.tar.bz2`; do
 ################################################################################/$BOILERPLATE/g" $dfile
     done
 
-    bzr-buildpackage -S --builder "make -f debian/rules get-desktop && dpkg-buildpackage -S -us -uc"
+    bzr-buildpackage -S --builder "make -f debian/rules get-l10n && dpkg-buildpackage -S -us -uc"
   fi
 done
